module.exports = defineTest({
	description: 'empty imports are assumed to contain side-effects'
});
